@@ -19,18 +19,28 @@ class Command(BaseCommand):
 
         logger.info(self.help)
 
-        with connection.cursor() as cursor:
-            cursor.execute('''select count(*)
-                            from ckk_item
-                            where id not in (select child_id from ckk_item_refs)''')
-            cnt, = cursor.fetchone()
+        def get_sql_str(s='count(*)'):
+            return f'''select {s}
+                        from (
+                                 (select *
+                                 from ckk_item)
+                                 except
+                                 (select *
+                                 from ckk_item
+                                 where id in (select child_id from ckk_item_refs))
+                             ) as a'''
 
-        self.pbar = tqdm(total=cnt)
+        with connection.cursor() as cursor:
+            print('Counting')
+
+            cursor.execute(get_sql_str())
+            cnt, = cursor.fetchone()
+            print(f'Count: {cnt}')
 
         with transaction.atomic():
-            for item in Item.objects.raw('''select *
-                                                    from ckk_item
-                                                    where id not in (select child_id from ckk_item_refs)'''):
+            print('Prepare')
+            self.pbar = tqdm(total=cnt)
+            for item in Item.objects.raw(get_sql_str(s='*')):
                 Item_refs.objects.get_or_create(child=item, parent_id=int(audo_top_level))
 
                 if self.pbar:
