@@ -460,10 +460,12 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
                 STMP_1__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_1.value_str) if STMP_1 else None,
                 STMP_2__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_2.value_str) if STMP_2 else None,
                 props=props,
-                version__isnull=False
-            ).order_by('-version')[0].version + inc
+                # version__isnull=False
+            ).order_by('-version')[0].version
             if res == None:
                 res = 1
+            else:
+                res += inc
         except IndexError:
             res = None
         settings.LOCKS.release('ItemManager.get_verstion')
