@@ -69,6 +69,7 @@ class Item_operations_viewManager(AuditManager):
             'deliting': record.deliting,
             'isFolder': record.isFolder,
             'relevant': record.relevant,
+            'confirmed': record.confirmed,
             'version': record.version,
             'section': record.section,
             'where_from': record.where_from,
@@ -91,6 +92,7 @@ class Item_operations_view(Hierarcy):
     document = ForeignKeyProtect(Documents, verbose_name='Документ', null=True, blank=True)
     refs_id = BigIntegerField()
     relevant = NameField()
+    confirmed = NameField()
     where_from = NameField()
     props = Item_add.get_prop_field()
     refs_props = Item_refsManager.props()
