@@ -24,14 +24,21 @@ class Item_refsQuerySet(AuditQuerySet):
             return cnt > 0
 
     def delete(self):
-        return super().delete()
+        from kaf_pas.ckk.models.item_qty import Item_qty
+        with transaction.atomic():
+            for item_refs in self:
+                Item_qty.objects.filter(child=item_refs.child, parent=item_refs.parent).delete()
+            return super().delete()
 
     def delete_with_checked(self):
         from kaf_pas.ckk.views.item_view import audo_top_level
+        from kaf_pas.ckk.models.item_qty import Item_qty
+
         with transaction.atomic():
-            for item_ref in self:
-                if not self.has_child_entered(id=item_ref.child.id):
-                    Item_refs.objects1.create(child=item_ref.child, parent_id=int(audo_top_level))
+            for item_refs in self:
+                Item_qty.objects.filter(child=item_refs.child, parent=item_refs.parent).delete()
+                if not self.has_child_entered(id=item_refs.child.id):
+                    Item_refs.objects1.create(child=item_refs.child, parent_id=int(audo_top_level))
             return super().delete()
 
     def get_or_create(self, defaults=None, **kwargs):
