@@ -100,6 +100,7 @@ def Item_view_Fetch2(request):
                                        t.refs_id,
                                        t.refs_props,
                                        t.relevant,
+                                       t.confirmed,
                                        t.section,
                                        t.version,
                                        t.where_from
@@ -119,6 +120,7 @@ def Item_view_Fetch2(request):
                                                                                        "refs_id" bigint,
                                                                                        "refs_props" bigint,
                                                                                        "relevant" text,
+                                                                                       "confirmed" text,
                                                                                        "section" text,
                                                                                        "STMP_1_id" bigint,
                                                                                        "STMP_2_id" bigint,
@@ -134,7 +136,8 @@ def Item_view_Fetch2(request):
                 request=request,
                 data=Item_operations_view.objects.raw(
                     raw_query=f'select * from {tmp_table_name}',
-                    function=Item_operations_viewManager.getRecord),
+                    function=Item_operations_viewManager.getRecord
+                ),
                 status=RPCResponseConstant.statusSuccess).response)
 
 
