@@ -2,10 +2,7 @@ import logging
 
 from django.core.management import BaseCommand
 
-from kaf_pas.ckk.models.item import Item
-from kaf_pas.ckk.models.item_view import Item_view
 from kaf_pas.kd.models.documents import DocumentManager
-from kaf_pas.kd.models.documents_ext import DocumentManagerExt
 
 logger = logging.getLogger(__name__)
 
@@ -17,4 +14,3 @@ class Command(BaseCommand):
         logger.info(self.help)
 
         DocumentManager.get_m_view()
-
