@@ -104,9 +104,7 @@ class Lotsman_documents_hierarcyManager(AuditManager):
             documentManagerExt=DocumentManagerExt(
                 logger=logger
             )
-        ).make_items(
-            lotsman_documents_hierarcy_view_record=Lotsman_documents_hierarcy_view.objects.get(id=data.get('id'))
-        )
+        ).make_items(lotsman_documents_hierarcy_view_record=Lotsman_documents_hierarcy_view.objects.get(id=data.get('id')))
 
         return data
 
