@@ -1,17 +1,21 @@
 import logging
 import os
 
+from bitfield import BitField
 from django.core.exceptions import ObjectDoesNotExist
 from django.db.models import TextField, CharField, UniqueConstraint, Q
 
 from isc_common import delete_drive_leter, get_drive_leter
+from isc_common.bit import TurnBitOn
+from isc_common.common.mat_views import refresh_mat_view
 from isc_common.fields.related import ForeignKeyProtect
 from isc_common.http.DSRequest import DSRequest
 from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsManager, CommonManagetWithLookUpFieldsQuerySet
 from isc_common.models.base_ref import Hierarcy
 from isc_common.models.tree_audit import TreeAuditModelManager
-from isc_common.progress import managed_progress
+from isc_common.progress import managed_progress, ProgressDroped
 from kaf_pas.ckk.models.attr_type import Attr_type
+from kaf_pas.production.models import progress_deleted
 
 logger = logging.getLogger(__name__)
 
@@ -27,6 +31,12 @@ class PathesQuerySet(CommonManagetWithLookUpFieldsQuerySet):
 
 
 class PathesManager(CommonManagetWithLookUpFieldsManager):
+    @staticmethod
+    def props():
+        return BitField(flags=(
+            ('enable_upload', 'Директория для закачки'),
+        ), default=1, db_index=True)
+
     def get_queryset(self):
         return PathesQuerySet(self.model, using=self._db)
 
@@ -133,13 +143,13 @@ class PathesManager(CommonManagetWithLookUpFieldsManager):
     # Только для перенаправленных на виндовый сервак вызовов !!!!
     def deleteFromRequest(self, request, removed=None, ):
         from django.db import transaction
-        from isc_common.management.commands.refresh_mat_views import refresh_mat_view
+        from isc_common.auth.models.user import User
+        from isc_common.models.deleted_progresses import Deleted_progresses
         from kaf_pas.kd.models.documents import DocumentManager
         from kaf_pas.kd.models.documents import Documents
         from kaf_pas.kd.models.uploades import Uploades
         from kaf_pas.kd.models.uploades_documents import Uploades_documents
         from kaf_pas.kd.models.uploades_log import Uploades_log
-        from isc_common.auth.models.user import User
 
         ids = request.GET.getlist('ids')
         request = DSRequest(request=request)
@@ -148,9 +158,9 @@ class PathesManager(CommonManagetWithLookUpFieldsManager):
         res = 0
         count = 0
         lotsman_count = 0
-        for i in range(0, len(ids), 2):
-            with transaction.atomic():
-                try:
+        try:
+            for i in range(0, len(ids), 2):
+                with transaction.atomic():
                     if ids[i + 1] == 'hide':
                         res += super().filter(id=ids[i]).soft_delete()
                     else:
@@ -163,7 +173,8 @@ class PathesManager(CommonManagetWithLookUpFieldsManager):
                                 qty=cnt - 1,
                                 user=request.user,
                                 message='Удаление путей размещения.',
-                                title='Выполнено'
+                                title='Выполнено',
+                                props=TurnBitOn(0, 0)
                         ) as progress:
 
                             for path in Pathes.objects_tree.get_descendants(
@@ -181,15 +192,19 @@ class PathesManager(CommonManagetWithLookUpFieldsManager):
 
                                 res += super().filter(id=path.id).delete()[0]
                                 logger.debug(f'Deleted: {res}')
-                                progress.step()
-                except Exception as ex:
-                    logger.error(ex)
+                                step_res = progress.step()
 
-        if count > 0:
-            refresh_mat_view('kd_documents_mview')
-        if lotsman_count > 0:
-            refresh_mat_view('kd_lotsman_documents_hierarcy_mview')
-        return res
+                                if step_res != 0:
+                                    raise ProgressDroped(progress_deleted)
+            if count > 0:
+                refresh_mat_view('kd_documents_mview')
+            if lotsman_count > 0:
+                refresh_mat_view('kd_lotsman_documents_hierarcy_mview')
+            return res
+
+        except ProgressDroped as ex:
+            Deleted_progresses.objects.filter(id_progress=progress.id, user=progress.user).delete()
+            raise ex
 
     def get_drive(self, id):
         try:
@@ -221,6 +236,7 @@ class Pathes(Hierarcy):
     path = TextField(verbose_name="Путь")
     virt_path = TextField(verbose_name="Мнимый путь", null=True, blank=True)
     attr_type = ForeignKeyProtect(Attr_type, verbose_name='Атрибут', null=True, blank=True)
+    props = PathesManager.props()
 
     @property
     def sep(self):
