@@ -2,8 +2,9 @@ import logging
 
 from isc_common.fields.related import ForeignKeyProtect
 from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
+
 from kaf_pas.kd.models.documents import Documents
-from kaf_pas.kd.models.uploades import Uploades
+from kaf_pas.kd.models.uploades import Uploades, UploadesManager
 
 logger = logging.getLogger(__name__)
 
@@ -15,6 +16,35 @@ class Uploades_documentsQuerySet(AuditQuerySet):
 
 class Uploades_documentsManager(AuditManager):
 
+    def deleteFromRequest(self, request, removed=None, ):
+        from isc_common.auth.models.user import User
+
+        ids = request.GET.getlist('ids')
+        user = User.objects.get(username=request.GET.get('ws_channel').split('_')[1])
+
+        res = 0
+        doc_cnt = 0
+        lotsman_cnt = 0
+
+        for i in range(0, len(ids), 2):
+            id = ids[i]
+            visibleMode = ids[i + 1]
+
+            if visibleMode != "none":
+                res += super().filter(id=id).soft_delete(visibleMode=visibleMode)
+            else:
+                res, _doc_cnt, _lotsman_cnt = UploadesManager.del_upload(
+                    id=Uploades_documents.objects.get(id=id).upload.id,
+                    document_id=id,
+                    user=user,
+                    doc_cnt=doc_cnt,
+                    last_step=len(ids) / 2 == i,
+                    lotsman_cnt=lotsman_cnt
+                )
+                doc_cnt += _doc_cnt
+                lotsman_cnt += _lotsman_cnt
+        return res
+
     @staticmethod
     def getRecord(record):
         document_view = record.document_view
