@@ -1,14 +1,13 @@
 import requests
+from django.conf import settings
 from django.http import HttpResponseRedirect
 
-from isc_common import ws
 from isc_common.http.DSRequest import DSRequest
 from isc_common.http.DSResponse import DSResponseUpdate, DSResponseAdd, DSResponse, JsonResponseWithException
 from isc_common.http.RPCResponse import RPCResponseConstant
 from isc_common.http.response import JsonResponse
 from kaf_pas.kd.models.pathes import Pathes
 from kaf_pas.kd.models.pathes_view import Pathes_view, Pathes_viewManager
-from django.conf import settings
 
 
 @JsonResponseWithException()
@@ -27,12 +26,12 @@ def Pathes_view_Fetch(request):
 
 @JsonResponseWithException()
 def Pathes_view_Add(request):
-    return JsonResponse(DSResponseAdd(data=Pathes.objects.createFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)
+    return JsonResponse(DSResponseAdd(data=Pathes.objects.createFromRequest(request=request, propsArr=['enable_upload']), status=RPCResponseConstant.statusSuccess).response)
 
 
 @JsonResponseWithException()
 def Pathes_view_Update(request):
-    return JsonResponse(DSResponseUpdate(data=Pathes.objects.updateFromRequest(request,propsArr=['enable_upload']), status=RPCResponseConstant.statusSuccess).response)
+    return JsonResponse(DSResponseUpdate(data=Pathes.objects.updateFromRequest(request=request, propsArr=['enable_upload']), status=RPCResponseConstant.statusSuccess).response)
 
 
 @JsonResponseWithException()
