@@ -154,7 +154,11 @@ def Production_order_SetPrevStatus(request):
 
 @JsonResponseWithException()
 def Production_order_SetStartStatus(request):
-    return JsonResponse(DSResponse(request=request, data=Production_order.objects.get_queryset().get_setStartStatus(request=request), status=RPCResponseConstant.statusSuccess).response)
+    return JsonResponse(DSResponse(request=request, data=Production_order.objects.get_queryset().get_setStartStatus(request=request), status=RPCResponseConstant.statusSuccess).response)\
+
+@JsonResponseWithException()
+def Production_order_getValue_made(request):
+    return JsonResponse(DSResponse(request=request, data=Production_order.objects.get_queryset().getValue_made(request=request), status=RPCResponseConstant.statusSuccess).response)
 
 
 @JsonResponseWithException()
