@@ -51,7 +51,7 @@ class Launch_item_refs(AuditModel):
     item_full_name = TextField()
     item_full_name_obj = JSONField(default=dict)
     qty = FloatField()
-    qty_per_one = FloatField(blank=True, null=True)
+    qty_per_one = FloatField()
 
     objects = Launch_item_refsManager()
     tree_objects = TreeAuditModelManager()
