@@ -1,5 +1,6 @@
 import logging
 
+from django.conf import settings
 from django.db import transaction, connection
 from django.db.models import PositiveIntegerField, OneToOneField, CASCADE, UniqueConstraint, Q
 from django.forms import model_to_dict
@@ -46,6 +47,7 @@ class Operation_resourcesManager(CommonManagetWithLookUpFieldsManager):
 
     @staticmethod
     def refresh_resource(apps=None, schema_editor=None):
+        settings.LOCKS.acquire('Operation_resourcesManager.refresh_resource')
         sql_text = '''select  operationitem_id, count(*)
                     from production_operation_resources
                     group by operationitem_id
@@ -74,6 +76,7 @@ class Operation_resourcesManager(CommonManagetWithLookUpFieldsManager):
                             # print(res)
                         else:
                             first_step = False
+        settings.LOCKS.release('Operation_resourcesManager.refresh_resource')
 
     def createFromRequest(self, request):
         request = DSRequest(request=request)
