@@ -1,5 +1,6 @@
 import logging
 
+from django.conf import settings
 from django.db import transaction, connection
 from django.db.models import PositiveIntegerField
 from django.forms import model_to_dict
@@ -26,6 +27,7 @@ class Operations_itemManager(CommonManagetWithLookUpFieldsManager):
 
     @staticmethod
     def refresh_num1():
+        settings.LOCKS.acquire('Operations_itemManager.refresh_num1')
         sql = '''select item_id,
                            count(*) 
                     from production_operations_item
@@ -56,10 +58,12 @@ class Operations_itemManager(CommonManagetWithLookUpFieldsManager):
                                 operations_item.save()
                                 cnt += 1
             print(f'Corected: {cnt} operations.')
+        settings.LOCKS.release('Operations_itemManager.refresh_num1')
         return cnt
 
     @staticmethod
     def refresh_num(apps, schema_editor):
+        settings.LOCKS.acquire('Operations_itemManager.refresh_num')
         sql = '''select num,
                        item_id,
                        count(*) 
@@ -88,6 +92,7 @@ class Operations_itemManager(CommonManagetWithLookUpFieldsManager):
                         num_max += 1
                         operations_item.num = num_max
                         operations_item.save()
+        settings.LOCKS.release('Operations_itemManager.refresh_num')
 
     @staticmethod
     def getRecord(record):
